@@ -159,6 +159,7 @@ driver = %s
 [metricd]
 metric_processing_delay = 1
 metric_cleanup_delay = 1
+workers = 1
 [statsd]
 resource_id = %s
 creator = admin
@@ -184,18 +185,18 @@ url = %s""" % (self.debug,
 
         c, _ = self._exec([
             "uwsgi",
-            "--plugin", "corerouter",
-            "--plugin", "python",
-            "--plugin", "http",
             "--http", "localhost:%d" % self.port,
             "--wsgi-file", spawn.find_executable("gnocchi-api"),
             "--master",
             "--die-on-term",
             "--lazy-apps",
+            "--no-orphans",
             "--enable-threads",
+            "--chdir", self.tempdir,
+            "--add-header", "Connection: close",
             "--pyargv", "--config-file=%s" % conffile,
         ],
-                          wait_for_line="spawned uWSGI worker")
+                          wait_for_line="WSGI app 0 \(mountpoint=''\) ready")
         self.addCleanup(self._kill, c.pid)
 
         self.http_url = "http://localhost:%d" % self.port
